@@ -895,7 +895,10 @@ class AssetDepreciationTable(CompanyReport):
             'closing_value',
             }
         for attr_name in grouped_attributes:
-            setattr(Grouper, attr_name, cached_property(adder(attr_name)))
+            descr = cached_property(adder(attr_name))
+            setattr(Grouper, attr_name, descr)
+            if hasattr(descr, '__set_name__'):
+                descr.__set_name__(Grouper, attr_name)
 
         return Grouper
 
@@ -1034,7 +1037,7 @@ class PrintDepreciationTable(Wizard):
         assets = Asset.search([
                 ('start_date', '<', self.start.end_date),
                 ('end_date', '>', self.start.start_date),
-                ('state', '=', 'running'),
+                ('state', '!=', 'draft'),
                 ])
         return action, {
             'ids': [a.id for a in assets],
